@@ -1,6 +1,6 @@
-# $Id: install.py 1385 2015-11-15 08:31:04Z mwall $
+# $Id: install.py 1447 2016-02-06 16:56:24Z mwall $
 # installer for the forecast extension
-# Copyright 2014 Matthew Wall
+# Copyright 2014-2016 Matthew Wall
 
 from setup import ExtensionInstaller
 
@@ -10,14 +10,18 @@ def loader():
 class ForecastInstaller(ExtensionInstaller):
     def __init__(self):
         super(ForecastInstaller, self).__init__(
-            version="3.0.8",
+            version="3.1.0",
             name='forecast',
             description='Generate and display weather and tide forecasts.',
             author="Matthew Wall",
             author_email="mwall@users.sourceforge.net",
             archive_services=['user.forecast.ZambrettiForecast',
-                              'user.forecast.WUForecast',
                               'user.forecast.NWSForecast',
+                              'user.forecast.WUForecast',
+                              'user.forecast.OWMForecast',
+                              'user.forecast.UKMOForecast',
+                              'user.forecast.AerisForecast',
+                              'user.forecast.WWOForecast',
                               'user.forecast.XTideForecast'],
             config={
                 'Forecast': {
@@ -30,14 +34,24 @@ class ForecastInstaller(ExtensionInstaller):
                         'lid': 'INSERT_LOCATION_ID_HERE (e.g., MAZ014)',
                         'foid': 'INSERT_FORECAST_OFFICE_ID_HERE (e.g., BOX)'},
                     'WU': {
-                        'api_key': 'INSERT_WU_API_KEY_HERE'}},
+                        'api_key': 'INSERT_WU_API_KEY_HERE'},
+                    'OWM': {
+                        'api_key': 'INSERT_OWM_API_KEY_HERE'},
+                    'UKMO': {
+                        'api_key': 'INSERT_UKMO_API_KEY_HERE',
+                        'location': 'INSERT_UK_LOCATION_HERE'},
+                    'Aeris': {
+                        'client_id': 'INSERT_AERIS_CLIENT_ID_HERE',
+                        'client_secret': 'INSERT_AERIS_CLIENT_SECRET_HERE'},
+                    'WWO': {
+                        'api_key': 'INSERT_WWO_API_KEY_HERE'}},
                 'DataBindings': {
                     'forecast_binding': {
                         'database': 'forecast_sqlite'}},
                 'Databases': {
                     'forecast_sqlite': {
                         'database_name': 'forecast.sdb',
-                        'driver': 'weedb.sqlite'}},
+                        'database_type': 'SQLite'}},
                 'StdReport': {
                     'forecast': {
                         'skin': 'forecast',
@@ -88,7 +102,9 @@ class ForecastInstaller(ExtensionInstaller):
                      'skins/forecast/icons/frzngdrzl.png',
                      'skins/forecast/icons/moon.png',
                      'skins/forecast/icons/moonphase.png',
+                     'skins/forecast/icons/moonrise.png',
                      'skins/forecast/icons/moonriseset.png',
+                     'skins/forecast/icons/moonset.png',
                      'skins/forecast/icons/pop.png',
                      'skins/forecast/icons/rain.png',
                      'skins/forecast/icons/raindrop.png',
@@ -101,7 +117,25 @@ class ForecastInstaller(ExtensionInstaller):
                      'skins/forecast/icons/sprinkles.png',
                      'skins/forecast/icons/sun.png',
                      'skins/forecast/icons/sunmoon.png',
+                     'skins/forecast/icons/sunrise.png',
                      'skins/forecast/icons/sunriseset.png',
+                     'skins/forecast/icons/sunset.png',
+                     'skins/forecast/icons/tE.png',
+                     'skins/forecast/icons/tENE.png',
+                     'skins/forecast/icons/tESE.png',
+                     'skins/forecast/icons/tN.png',
+                     'skins/forecast/icons/tNE.png',
+                     'skins/forecast/icons/tNNE.png',
+                     'skins/forecast/icons/tNNW.png',
+                     'skins/forecast/icons/tNW.png',
+                     'skins/forecast/icons/tS.png',
+                     'skins/forecast/icons/tSE.png',
+                     'skins/forecast/icons/tSSE.png',
+                     'skins/forecast/icons/tSSW.png',
+                     'skins/forecast/icons/tSW.png',
+                     'skins/forecast/icons/tW.png',
+                     'skins/forecast/icons/tWNW.png',
+                     'skins/forecast/icons/tWSW.png',
                      'skins/forecast/icons/thermometer-blue.png',
                      'skins/forecast/icons/thermometer-dewpoint.png',
                      'skins/forecast/icons/thermometer-red.png',
